==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebForOfStateDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebForOfStateDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateDetailDescription, _super);
    function WebForOfStateDetailDescription() {
        var _this = _super.call(this) || this;
        _this.m = 0;
        _this.l = 0;
        return _this;
    }
    WebForOfStateDetailDescription.prototype.get_type = function () {
        return "WebForOfStateDetail";
    };
    Object.defineProperty(WebForOfStateDetailDescription.prototype, "startIndex", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("StartIndex");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebForOfStateDetailDescription.prototype, "chunkSize", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("ChunkSize");
        },
        enumerable: true,
        configurable: true
    });
    WebForOfStateDetailDescription.$t = markType(WebForOfStateDetailDescription, 'WebForOfStateDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebForOfStateDetailDescription.__marshalByValue1 = true;
    WebForOfStateDetailDescription.__marshalByValueAlias1 = "ForOfStateDetail";
    return WebForOfStateDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebForOfStateDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebForOfStateDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebForOfStateDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfStateDetailDescription, _super);
    function WebForOfStateDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = 0;
        _this.i = 0;
        return _this;
    }
    WebForOfStateDetailDescription.prototype.get_type = function () {
        return "WebForOfStateDetail";
    };
    Object.defineProperty(WebForOfStateDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebForOfStateDetailDescription.prototype, "startIndex", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("StartIndex");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebForOfStateDetailDescription.prototype, "chunkSize", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("ChunkSize");
        },
        enumerable: false,
        configurable: true
    });
    WebForOfStateDetailDescription.$t = markType(WebForOfStateDetailDescription, 'WebForOfStateDetailDescription', Description.$);
    WebForOfStateDetailDescription.__marshalByValue = true;
    WebForOfStateDetailDescription.__marshalByValueAlias = "ForOfStateDetail";
    return WebForOfStateDetailDescription;
}(Description));
export { WebForOfStateDetailDescription };
